@@ -30,7 +30,7 @@ def main(ctx, config, outconfig, configalias, inputalias):
               help='apply human blur before processing')
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def img_cr(ctx, arg1, **kwargs):
-    """get illuminance and contrast data from images 
+    """get illuminance and contrast data from images
     (assumes all images are the same size and view parameters)"""
     if kwargs['opts']:
         kwargs['opts'] = False
@@ -58,6 +58,7 @@ def img_cr(ctx, arg1, **kwargs):
 @main.command()
 @click.argument('arg1', callback=clk.are_files)
 @click.option('-out', help='basename of output')
+@click.option('-evopts', help='extra options for evalglare', default="")
 @click.option('-values', callback=clk.split_str, default='T1 T2 dgp E_v ugr',
               help="which values to report, can be: 'dgp', 'av_lum', 'E_v',"
               "'lum_backg', 'E_v_dir', 'dgi', 'ugr', 'vcp', 'cgi', "
@@ -79,7 +80,8 @@ def evalglare(ctx, arg1, **kwargs):
     else:
         try:
             out = kwargs['out']
-            results = cst.pool_call(img.evalglare, arg1)
+            results = cst.pool_call(img.evalglare, arg1,
+                                    kwargs=dict(options=kwargs['evopts']))
             imgkeys = []
             for i,a in enumerate(arg1):
                 try:
@@ -99,7 +101,7 @@ def evalglare(ctx, arg1, **kwargs):
                     for j in range(len(arg1)):
                         if val == 'srcvalues':
                             for k, src in enumerate(results[j]['srcs']):
-                                r = [imgkeys[j], k] + [src[m] for m in 
+                                r = [imgkeys[j], k] + [src[m] for m in
                                                        kwargs['srcvalues']]
                                 pline = '\t'.join([f'{i: <15}' for i in r])
                                 print(pline, file=f)
@@ -129,10 +131,10 @@ def evalglare(ctx, arg1, **kwargs):
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def kde(ctx, arg1, **kwargs):
     """generate KDE for samples"""
-    
+
     if kwargs['opts']:
         kwargs['opts'] = False
-        clk.echo_args(arg1, arg2, outpref, **kwargs)
+        clk.echo_args(arg1, **kwargs)
     else:
         try:
             aS = np.loadtxt(arg1)[:,kwargs['idx']]
@@ -198,7 +200,7 @@ def get_rdif(aS, a2S, i, select=None, relative=True):
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def kde_error(ctx, arg1, arg2, outpref, **kwargs):
     """calculate error between 2 2D data files using gaussian KDE"""
-    
+
     if kwargs['opts']:
         kwargs['opts'] = False
         clk.echo_args(arg1, arg2, outpref, **kwargs)
@@ -258,6 +260,18 @@ def kde_error(ctx, arg1, arg2, outpref, **kwargs):
               help="linear regression (r^2)")
 @click.option('--spearman/--no-spearman', default=True)
 @click.option('--pearson/--no-pearson', default=True)
+@click.option('--rbc/--no-rbc', default=False)
+@click.option('--mae/--no-mae', default=False, help="mean absolute error")
+@click.option('--rmae/--no-rmae', default=False,
+              help="relative mean absolute error")
+@click.option('--msd/--no-msd', default=False,
+              help="mean signed deviation")
+@click.option('--rmsd/--no-rmsd', default=False,
+              help="relative mean signed deviation")
+@click.option('--rmse/--no-rmse', default=False,
+              help="root mean square error")
+@click.option('--rrmse/--no-rrmse', default=False,
+              help="relative root mean square error")
 @click.option('--pvals/--no-pvals', default=False)
 @click.option('-drange', callback=clk.split_int,
               help="index range for data series, if None gets all")
@@ -268,7 +282,7 @@ def kde_error(ctx, arg1, arg2, outpref, **kwargs):
 @click.option('-labels', callback=clk.split_str,
               help="input custom series labels, by default uses "
               "file name and index or --header option")
-@click.option('--opts','-opts', is_flag=True,
+@click.option('--opts', '-opts', is_flag=True,
               help="check parsed options")
 @click.option('--debug', is_flag=True,
               help="show traceback on exceptions")
@@ -297,6 +311,7 @@ def corr(dataf, **kwargs):
                                     kwargs=kwargs)
             outs += [[f'{i:.04f}' for i in r] for r in results]
             ot = np.array(outs).T
+            print(f'N={len(xs[0])}')
             print('\t'.join([f'{i: <20}' for i in ['stat'] + labels]))
             for i in ot:
                 print('\t'.join([f'{j: <20}' for j in i]))
@@ -307,6 +322,50 @@ def corr(dataf, **kwargs):
     return 'corr', kwargs
 
 
+@main.command()
+@click.argument('dataf', callback=clk.are_files)
+@click.option('-x_vals', default="0,0",
+              callback=clk.tup_int, help="index for xvals")
+@click.option('-y_vals', default="-1", callback=clk.tup_int,
+              help="index for yvals")
+@click.option('--header/--no-header', default=False,
+              help="indicates that data has a header row to get "
+              "series labels (overridden by labels)")
+@click.option('--xheader/--no-xheader', default=False,
+              help="indicates that data has a header column to get x-axis "
+              "labels (overridden by xlabels)")
+@click.option('--rows/--no-rows', default=False,
+              help="get data rows instead of columns")
+@click.option('-drange', callback=clk.split_int,
+              help="index range for data series, if None gets all")
+@click.option('--opts', '-opts', is_flag=True,
+              help="check parsed options")
+@click.option('--debug', is_flag=True,
+              help="show traceback on exceptions")
+def qq(dataf, **kwargs):
+    '''
+    output qq pairs, if more than 1 series are concatenated and calculated
+    together
+    '''
+    if kwargs['opts']:
+        kwargs['opts'] = False
+        clk.echo_args(dataf, **kwargs)
+    else:
+        try:
+            a1 = cst.kwarg_match(cst.read_data, kwargs)
+            xs, ys, l2 = cst.read_all_data(dataf, **a1)
+            xs = np.concatenate(xs)
+            ys = np.concatenate(ys)
+            result = hs.qq(xs, ys)
+            for x,y in result:
+                print(f"{x}\t{y}")
+        except click.Abort:
+            raise
+        except Exception as ex:
+            clk.print_except(ex, kwargs['debug'])
+    return 'qq', kwargs
+
+
 @main.command()
 @click.argument('arg1', callback=clk.is_file)
 @click.argument('arg2', callback=clk.is_file)
@@ -321,7 +380,7 @@ def corr(dataf, **kwargs):
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def logist_error(ctx, arg1, arg2, outpref, coef, **kwargs):
     """calculate error between 2 2D data files using softmax distributions from logistic regression"""
-    
+
     if kwargs['opts']:
         kwargs['opts'] = False
         clk.echo_args(arg1, arg2, outpref, coef, **kwargs)
@@ -367,7 +426,7 @@ def logist_error(ctx, arg1, arg2, outpref, coef, **kwargs):
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def softmax(ctx, coef, **kwargs):
     """calculate softmax based on coef file (from )"""
-    
+
     if kwargs['opts']:
         kwargs['opts'] = False
         clk.echo_args(coef, **kwargs)
